@@ -30,7 +30,10 @@ pub struct SenderReport {
 impl SenderReport {
     /// builder returns a new ReportBuilder.
     pub fn builder() -> ReportBuilder {
-        ReportBuilder::default()
+        ReportBuilder {
+            is_rr: false,
+            ..Default::default()
+        }
     }
 
     async fn is_closed(&self) -> bool {
@@ -48,7 +51,7 @@ impl SenderReport {
             if let Some(close) = close_rx.take() {
                 close
             } else {
-                return Err(Error::ErrIncorrectReceiverReportCloseRx);
+                return Err(Error::ErrInvalidCloseRx);
             }
         };
 
